summaryrefslogtreecommitdiff
path: root/obnamlib/plugins/show_plugin.py
diff options
context:
space:
mode:
authorLars Wirzenius <liw@liw.fi>2012-07-07 16:50:48 +0100
committerLars Wirzenius <liw@liw.fi>2012-07-07 16:50:48 +0100
commit9ca6591952d3a400f26f670e200df98226e66698 (patch)
tree1daa8214e90dfd213ad7b2e4d983b7b6c554d317 /obnamlib/plugins/show_plugin.py
parent9033d8e27ce94548848cf9845462b8aa546a9651 (diff)
downloadobnam-9ca6591952d3a400f26f670e200df98226e66698.tar.gz
Make diff command obey --verbose instead of --quiet
Diffstat (limited to 'obnamlib/plugins/show_plugin.py')
-rw-r--r--obnamlib/plugins/show_plugin.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/obnamlib/plugins/show_plugin.py b/obnamlib/plugins/show_plugin.py
index a3820b22..6c8ad38c 100644
--- a/obnamlib/plugins/show_plugin.py
+++ b/obnamlib/plugins/show_plugin.py
@@ -187,16 +187,16 @@ class ShowPlugin(obnamlib.ObnamPlugin):
change_char is a single char (+,- or *) indicating whether a file
got added, removed or altered.
If --quiet, just show the file's full name, otherwise show the same
details for the file you'd get with ls.
'''
- if self.app.settings['quiet']:
- print '%s %s' % (change_char, fullname)
- else:
+ if self.app.settings['verbose']:
sys.stdout.write('%s ' % change_char)
self.show_item(gen, fullname)
+ else:
+ print '%s %s' % (change_char, fullname)
def show_diff_for_common_file(self, gen1, gen2, fullname, subdirs):
changed = False
@@ -187,16 +187,16 @@ class ShowPlugin(obnamlib.ObnamPlugin):
change_char is a single char (+,- or *) indicating whether a file
got added, removed or altered.
- If --quiet, just show the file's full name, otherwise show the same
- details for the file you'd get with ls.
+ If --verbose, just show all the details as ls shows, otherwise
+ show just the file's full name.
'''